import requests
import argparse
import bibtexparser as btp
from word2Tex.fixBibTex import resolve_ID_matches

def doi_lookup(doi):
    """queries for article data based on given doi

    :param doi: DOI to lookup
    :type doi: str
    :return: reference information
    :rtype: dict
    """
    url = "https://dx.doi.org/" + doi
    headers = {"accept": "application/x-bibtex"}
    r = requests.get(url, headers = headers)
    bp = btp.bparser.BibTexParser(interpolate_strings=False)
    db = bp.parse(r.text)
    if len(db.entries) == 0:
        print(f'No reference found for DOI: {doi}')
        return
    else:
        print(f'Found reference for DOI: {doi}')
        print(r.text)
        return db.entries[0]


def add_to_bibtex(bib_fn, doi):
    """Lookup a doi and add the reference to a bibtex file
    :param bib_fn: path to bibtex file
    :type bib_fn: str
    :param doi: doi reference
    :type doi: str
    """
    ref = doi_lookup(doi)
    if ref is None:
        print('No reference added to bibtex database')
        return

    if os.path.isfile(bib_fn):
        with open(bib_fn) as f:
            db = btp.load(f)
    else:
        db = btp.bibdatabase.BibDatabase()

    db.entries.append(ref)
    db = resolve_ID_matches(db)
    with open(bib_fn, 'w') as f:
        btp.dump(db, f)

    ID = ref['ID']
    print(f'Added new reference ({ID}) to bibtex db')

def main():
    parser = argparse.ArgumentParser(prog='doi2bib',
                                     description='Adds new reference to '
                                     'bibtex library using the doi.')
    parser.add_argument('file', help='.txt or .bib file to add to')
    parser.add_argument('doi', help='DOI of reference to add')
    args = parser.parse_args()
    add_to_bibtex(args.file, args.doi)

if __name__ == "__main__":
    main()



import setuptools
import os

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.md'), 'r') as fh:
    long_description = fh.read()

requirementPath = os.path.join(here, 'requirements.txt')
install_requires = [] # Examples: ["gunicorn", "docutils>=0.3", "lxml==0.5a7"]
if os.path.isfile(requirementPath):
    with open(requirementPath) as f:
        install_requires = f.read().splitlines()

setuptools.setup(
    name='word2Tex',
    version='0.0.9',
    author='Roshan Nanu',
    author_email='roshan.nanu@gmail.com',
    description='package for moving manuscripts from Word to LaTeX',
    long_description_content_type='text/markdown',
    long_description=long_description,
    url='https://github.com/nubs01/word2Tex',
    license='MIT',
    packages=setuptools.find_packages(),
    entry_points = {
        'console_scripts': [
            'cite2Tex=word2Tex.cite2Tex:main',
            'fixBibTex=word2Tex.fixBibTex:main',
            'doi2bib=word2Tex.doi2bib:main'
        ]
    },
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License'],
    keywords=('word2Tex cite2Tex fixBibTex bibtex latex Word citation '
              'cite convert'),
    python_requires='>=3.6',
    install_requires=install_requires,
    include_package_data=True,
    package_data={}
)




